wsireg.reg\_shapes package
==========================

Submodules
----------

wsireg.reg\_shapes.reg\_shapes module
-------------------------------------

.. automodule:: wsireg.reg_shapes.reg_shapes
   :members:
   :undoc-members:
   :show-inheritance:
